# Med-Imagetools: Transparent and Reproducible Medical Image Processing Pipelines in Python

{%
  include-markdown "../README.md"
  start="<!--intro-start-->"
  end="<!--intro-end-->"
  rewrite-relative-urls=false
%}
